
%% Yeast experiments
% Loads the Orlando experimental data, runs Genie3 and DSS, it also loads
% the pr curve from the inferelator results and compares the results
% against the putative ground truth network
wtFile='../Data/OrlandoWT.csv';
mFile='../Data/OrlandoMutants.csv';
rng(130784); %%random seed
%wildtype

[wtData,headers]=myReadTable(wtFile);
%get rid of time column
for ii=1:length(wtData)
    temp=wtData{ii};
    wtData{ii}=temp(:,2:end);
end;


%Mutants

[mData,headers]=myReadTable(mFile);
%get rid of time column
for ii=1:length(wtData)
    temp=mData{ii};
    mData{ii}=temp(:,2:end);
end;

% wild type and mutant data

tData={wtData{:},mData{:}};
 

% Similarity matrix

sfile='../Data/similarity.data';
S=dlmread(sfile,',')

%normalize to [0-1]
S=S./100;


%% substracting the mean
% additionally get rid of the post transcriptional elements, leaving the option of
%adding them later if it's interesting.


    for jj=1:length(wtData)
       wtData{jj}= bsxfun(@minus,wtData{jj},mean(wtData{jj}));
       temp=wtData{jj};
       wtData{jj}=temp(:,setdiff(1:size(temp,2),[1,5,6,11,14,15]));
    end
    
    
    for jj=1:length(mData)
       mData{jj}= bsxfun(@minus,mData{jj},mean(mData{jj}));
       temp=mData{jj};
       mData{jj}=temp(:,setdiff(1:size(temp,2),[1,5,6,11,14,15]));
    end
    
    
    for jj=1:length(tData)
       tData{jj}= bsxfun(@minus,tData{jj},mean(tData{jj}));
       temp=tData{jj};
       tData{jj}=temp(:,setdiff(1:size(temp,2),[1,5,6,11,14,15]));
    end
    
    
    %% Ground truth network
[M,N]=size(wtData{1});

H=zeros(16);
H(1,:)=[0 0 0 1 0 0 0 0 0 0 1 1 0 0 1 0];
H(2,:)=[0 0 1 1 0 0 0 0 0 0 1 0 1 1 1 1];
H(3,:)=[0 1 1 0 0 0 1 0 0 1 0 1 1 0 0 1];
H(4,:)=[0 0 0 0 0 0 0 0 0 0 1 0 0 1 0 0];
H(5,:)=[1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0];
H(6,:)=[0 0 0 1 0 0 0 0 0 0 1 0 0 0 1 0];
H(7,:)=[0 0 1 1 0 0 0 0 0 0 0 0 1 0 0 1];
H(8,:)=[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0];
H(9,:)=[0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 1];
H(10,:)=[0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0];
H(11,:)=[0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0];
H(12,:)=[0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0];
H(13,:)=[0 0 0 0 0 0 1 1 1 1 0 0 0 0 0 0];
H(14,:)=[0 0 1 1 0 0 0 0 0 0 0 0 1 0 1 1];
H(15,:)=[0 0 0 1 0 0 0 1 0 0 1 0 1 1 0 0];
H(16,:)=[0 0 0 0 0 0 0 1 1 1 0 0 0 0 0 0];



%%

clear genie3tData;
clear genie3wtData;
clear genie3mData;

%normalize for genie3
  for ii=1:length(tData)
      genie3tData{ii}=zscore(tData{ii})
      if(ii<=length(wtData))
         genie3wtData{ii}=zscore(wtData{ii});
         genie3mData{ii}=zscore(mData{ii});
      end;

  end;
  VIMwt=genie3_time(genie3wtData);
  VIMm=genie3_time(genie3mData);
  VIMt=genie3_time(genie3tData);


%% Sample with and without similarity matrix
parameters=DSSparameters;
% for mutants and wild type we use different prior parameters for sigmaseq
parametersm=DSSparameters;
parametersm.E1=10;
parametersm.E2=0.1;

[resultsWT,vdxiwt,Qwt]=DSS(M,N,wtData,[],@cellFFTSpectrum,[],parametersm);
resultsWTs=DSS(M,N,wtData,[],@cellFFTSpectrum,S,parametersm);



[resultsM,vdxim,Qm]=DSS(M,N,mData,[],@cellFFTSpectrum,[],parametersm);
resultsMs=DSS(M,N,mData,[],@cellFFTSpectrum,S,parametersm);

resultsT=DSS(M,N,tData,[],@cellFFTSpectrum,[],parameters);

[resultsTs,vdxit,Qt]=DSS(M,N,tData,[],@cellFFTSpectrum,S,parameters);

estWT=mean(resultsWT.H(:,:,end-1000:end),3);
estWTs=mean(resultsWTs.H(:,:,end-1000:end),3);
estM=mean(resultsM.H(:,:,end-1000:end),3);
estMs=mean(resultsMs.H(:,:,end-1000:end),3);
estT=mean(resultsT.H(:,:,end-1000:end),3);
estTs=mean(resultsTs.H(:,:,end-1000:end),3);



%%


thres=0.5;

genesn={'SWI5';'YHP1';'SWI4';'FKH1';'SIC1';'ACE2';'YOX1';'STB1';'NRM1';'WHI5';'FKH2';'MCM1';'SWI6';'HCM1';'NDD1';'MBP1'};
 
  
  

  plotGNR(estWT-eye(N)>thres,genesn,'Inferred Network Wildtype');
  plotGNR(estWTs-eye(N)>thres,genesn,'Inferred Network Wildtype with Similarity');
  plotGNR(estM-eye(N)>thres,genesn,'Inferred Network Mutant');
  plotGNR(estMs-eye(N)>thres,genesn,'Inferred Network Mutant with Similarity');
  plotGNR(estT-eye(N)>thres,genesn,'Inferred Network WT and Mutant');
  plotGNR(estTs-eye(N)>thres,genesn,'Inferred Network WT and Mutant with similarity');
  
%%
% 

 writeInferelator(wtData,M,genesn,H);
 writeInferelator(mData,M,genesn,H);
 writeInferelator(tData,M,genesn,H);
%   
 %%
  

 
 
 
 clear acum1;
clear acum2;
acum1=vdxiwt{1};
acum2=Qwt{1};
for ii=2:size(wtData)
     acum1=acum1+vdxiwt{ii};
     acum2=acum2+Qwt{ii};
end
lambda=linspace(0,100,100);

fit = glmnet(acum2, acum1)
%c=cvglmnetCoef(cvfit);
%c=acum2\acum1
%c=reshape(c(2:end),7,7);
cwt=glmnetCoef(fit);
cwt=reshape(cwt(2:end,end),16,16);
cwt=cwt';

clear acum1;
clear acum2;
acum1=vdxim{1};
acum2=Qm{1};
for ii=2:size(mData)
     acum1=acum1+vdxim{ii};
     acum2=acum2+Qm{ii};
end
lambda=linspace(0,100,100);

fit = glmnet(acum2, acum1)
%c=cvglmnetCoef(cvfit);
%c=acum2\acum1
%c=reshape(c(2:end),7,7);
cm=glmnetCoef(fit);
cm=reshape(cm(2:end,end),16,16);
cm=cm';
 
clear acum1;
clear acum2;
acum1=vdxit{1};
acum2=Qt{1};
for ii=2:size(tData)
     acum1=acum1+vdxit{ii};
     acum2=acum2+Qt{ii};
end
lambda=linspace(0,100,100);

fit = glmnet(acum2, acum1)
%c=cvglmnetCoef(cvfit);
%c=acum2\acum1
%c=reshape(c(2:end),7,7);
ct=glmnetCoef(fit);
ct=reshape(ct(2:end,end),16,16);
ct=ct';
 
 
 
 
 
 clear estWTv;
clear estMv;
clear estTv;
clear estWTsv;
clear estMsv;
clear estTsv;
clear VIMwtv;
clear VIMmv;
clear VIMtv;
clear cwtv;
clear cmv;
clear ctv;





clear Hv;



counter=1;
[M,N]=size(estWT);
for ii=1:M
    for jj=1:N
        if(ii~=jj)
            estWTv(counter)=estWT(ii,jj);
            estMv(counter)=estM(ii,jj);
            estTv(counter)=estT(ii,jj);
            estWTsv(counter)=estWTs(ii,jj);
            estMsv(counter)=estMs(ii,jj);
            estTsv(counter)=estTs(ii,jj);
            
            
            VIMwtv(counter)=VIMwt(ii,jj);
            VIMmv(counter)=VIMm(ii,jj);
            VIMtv(counter)=VIMt(ii,jj);
            
            cwtv(counter)=cwt(ii,jj);
            cmv(counter)=cm(ii,jj);
            ctv(counter)=ct(ii,jj);
            
            Hv(counter)=H(ii,jj);
         
            counter=counter+1;
        end;
    end;
end;

%% pr curve



[prec, tpr, fpr, thresh]=prec_rec(estWTv,Hv,'spike','plotPR',1,'plotBaseline',1,'holdFigure',1);    
auroc=trapz([0; fpr], [0; tpr]);
auprDSSwt=trapz([0; tpr],[1 ; prec]);
            
[prec2, tpr2, fpr2, thresh2]=prec_rec(estMv,Hv,'spikeandseq','style','+-','plotPR',1,'plotBaseline',1,'holdFigure',1);
auprDSSm=trapz([0; tpr2],[1 ; prec2]);
auroc2=trapz([0; fpr2], [0; tpr2]);
[prec3, tpr3, fpr3, thresh3]=prec_rec(estTv,Hv,'genie3','plotPR',1,'plotBaseline',1,'holdFigure',1)
auprDSSt=trapz([0; tpr3],[1 ; prec3]);
auroc3=trapz([0; fpr3], [0; tpr3]);


[prec, tpr, fpr, thresh]=prec_rec(estWTsv,Hv,'spike','plotPR',1,'plotBaseline',1,'holdFigure',1);    
auroc=trapz([0; fpr], [0; tpr]);
auprDSSswt=trapz([0; tpr],[1 ; prec]);
            
[prec2, tpr2, fpr2, thresh2]=prec_rec(estMsv,Hv,'spikeandseq','style','+-','plotPR',1,'plotBaseline',1,'holdFigure',1);
auprDSSsm=trapz([0; tpr2],[1 ; prec2]);
auroc2=trapz([0; fpr2], [0; tpr2]);
[prec3, tpr3, fpr3, thresh3]=prec_rec(estTsv,Hv,'genie3','plotPR',1,'plotBaseline',1,'holdFigure',1)
auprDSSst=trapz([0; tpr3],[1 ; prec3]);
auroc3=trapz([0; fpr3], [0; tpr3]);




[prec, tpr, fpr, thresh]=prec_rec(VIMwtv,Hv,'spike','plotPR',1,'plotBaseline',1,'holdFigure',1);    
auroc=trapz([0; fpr], [0; tpr]);
auprgenie3wt=trapz([0; tpr],[1 ; prec]);
            
[prec2, tpr2, fpr2, thresh2]=prec_rec(VIMmv,Hv,'spikeandseq','style','+-','plotPR',1,'plotBaseline',1,'holdFigure',1);
auprgenie3m=trapz([0; tpr2],[1 ; prec2]);
auroc2=trapz([0; fpr2], [0; tpr2]);
[prec3, tpr3, fpr3, thresh3]=prec_rec(VIMtv,Hv,'genie3','plotPR',1,'plotBaseline',1,'holdFigure',1)
auprgenie3t=trapz([0; tpr3],[1 ; prec3]);
auroc3=trapz([0; fpr3], [0; tpr3]);


[prec, tpr, fpr, thresh]=prec_rec(cwtv,Hv,'spike','plotPR',1,'plotBaseline',1,'holdFigure',1);    
auroc=trapz([0; fpr], [0; tpr]);
auprlassowt=trapz([0; tpr],[1 ; prec]);
            
[prec2, tpr2, fpr2, thresh2]=prec_rec(cmv,Hv,'spikeandseq','style','+-','plotPR',1,'plotBaseline',1,'holdFigure',1);
auprlassom=trapz([0; tpr2],[1 ; prec2]);
auroc2=trapz([0; fpr2], [0; tpr2]);
[prec3, tpr3, fpr3, thresh3]=prec_rec(ctv,Hv,'genie3','plotPR',1,'plotBaseline',1,'holdFigure',1)
auprlassot=trapz([0; tpr3],[1 ; prec3]);
auroc3=trapz([0; fpr3], [0; tpr3]);

prinfer=dlmread('../Data/Inferelator/yeastWT/curve.csv','\t');
prec5=prinfer(:,1);
tpr5=prinfer(:,2);

auprInferwt=trapz([0; tpr5],[1 ; prec5]);

prinfer=dlmread('../Data/Inferelator/yeastMutants/curve.csv','\t');
prec5=prinfer(:,1);
tpr5=prinfer(:,2);

auprInferm=trapz([0; tpr5],[1 ; prec5]);

prinfer=dlmread('../Data/Inferelator/yeastboth/curve.csv','\t');
prec5=prinfer(:,1);
tpr5=prinfer(:,2);

auprInfert=trapz([0; tpr5],[1 ; prec5]);

%%
close all;
subplot(2,2,[1,2]);
plot(wtData{1});
xlabel('Time','FontSize',14);
ylabel('Expression level','FontSize',14);
title('Wild type S. cerevisae expression level profiles','FontSize',16);

subplot(2,2,3)
dss=[auprDSSwt auprDSSm auprDSSt];
dssS=[auprDSSswt auprDSSsm auprDSSst];
tgenie3=[auprgenie3wt auprgenie3m auprgenie3t];
inferelator=[auprInferwt auprInferm auprInfert];
lassoQ=[auprlassowt auprlassom auprlassot];

fig=bar([1 2 3],[dss' dssS' tgenie3' inferelator' lassoQ'])
 legend('DSS','DSS with S','genie3','Inferelator','LASSO');
 ax=gca;
set(ax, 'XTick',[1 2 3],'XTickLabel',{'Wild Type','Mutant','Wild type and mutant' },'FontSize',12);
ylabel('AUPR','FontSize',14);
xlabel('Simulation data set','FontSize',14);
title('AUPR for the  S. cerivisae cell cycle network','FontSize',16);
legend('location','southwest')
%colormap(fig,'parula');

subplot(2,2,4)
 A=(estTs-eye(N)>0.2);
% A=H;
r =  1;
theta = linspace(0,2*pi,N+1)'; theta(end) = [];
xy = r .* [cos(theta) sin(theta)];
p = symrcm(A);
%A = A(p,p);
txt = genesn
%txt = txt(p,:);
%# labels of nodes


%# show nodes and edges
line(xy(:,1), xy(:,2), 'LineStyle','none', ...
    'Marker','.', 'MarkerSize',15, 'Color','g')
hold on
[gr]=gplotd(A, xy, 'b-')
axis([-1 1 -1 1]); axis equal off
hold off

%# show node labels
h = text(xy(:,1).*1.05, xy(:,2).*1.05, txt, 'FontSize',16,'FontWeight','bold' );
%set(h, {'Rotation'},num2cell(theta*180/pi))
title('Inferred Network','FontSize',16);
